@@ -215,12 +215,11 @@ commandsList progversion othercmds =
   ,"+stockquotes              download market prices from AlphaVantage"
   ,""
     -----------------------------------------80-------------------------------------
-  ,bold' "MANAGING DATA (error checking, file management, version control..)"
+  ,bold' "MANAGING DATA (error checking, version control..)"
   ," check                    check for various kinds of error in the data"
   ,"+check-fancyassertions    check more powerful balance assertions"
   ,"+check-tagfiles           check file paths in tag values exist"
   ," diff                     compare account transactions in two journal files"
-  ," files                    show data files in use"
   ,"+git                      simple version management with git"
   ,"+pijul                    simple version management with pijul"
   ,""
@@ -236,7 +235,7 @@ commandsList progversion othercmds =
   ,bold' "VERSATILE REPORTS (more complex/versatile reporting commands)"
   ," activity                 show a simple bar chart of posting counts per period"
   ," balance (bal)            show balance changes, end balances, budgets, gains.."
-  ," bar                      show a balance report as a simple bar chart"
+  ,"+bar                      show a balance report as a simple bar chart"
   ,"+lots                     show a commodity's lots"
   ,"+plot                     create charts from balance reports, in terminal or GUI"
   ," print                    show transactions or export journal data"
@@ -249,12 +248,12 @@ commandsList progversion othercmds =
   ," codes                    show transaction codes"
   ," commodities              show commodity/currency symbols"
   ," descriptions             show full transaction descriptions (payee and note)"
+  ," files                    show data files in use"
   ," notes                    show note part of transaction descriptions"
   ," payees                   show payee names"
   ," prices                   show historical market prices"
   ," stats                    show journal statistics"
   ," tags                     show tag names"
-  ," test                     run self tests"
   ,""
     -----------------------------------------80-------------------------------------
   ,bold' "UIS (other user interfaces)"
@@ -267,7 +266,8 @@ commandsList progversion othercmds =
   ," hledger -h                       show hledger's command-line help"
   ," hledger CMD -h                   show CMD's command-line help and manual"
   ," hledger help [-i|-m|-p] [TOPIC]  show hledger's manual with info, man, or pager"
-  ," hledger demo [DEMO] -- [ASCOPTS] show brief demos on various topics"
+  ," hledger demo [DEMO] [-- ASCOPTS] show brief demos on various topics"
+  ," hledger test      [-- TASTYOPTS] run self tests"
   ," https://hledger.org              html manuals, tutorials, support.."
   ,""
     -----------------------------------------80-------------------------------------
