@@ -22,7 +22,7 @@ import Control.Monad.Trans (liftIO)
 import Data.Char (toUpper, toLower)
 import Data.Either (isRight)
 import Data.Functor.Identity (Identity(..))
-import Data.List (isPrefixOf)
+import Data.List (isPrefixOf, nub)
 import Data.Maybe (fromJust, fromMaybe, isJust)
 import Data.Text (Text)
 import qualified Data.Text as T
@@ -30,7 +30,7 @@ import qualified Data.Text.IO as T
 import qualified Data.Text.Lazy as TL
 import qualified Data.Text.Lazy.IO as TL
 import Data.Time.Calendar (Day)
-import Data.Time.Format (formatTime, defaultTimeLocale, iso8601DateFormat)
+import Data.Time.Format (formatTime, defaultTimeLocale)
 import Lens.Micro ((^.))
 import Safe (headDef, headMay, atMay)
 import System.Console.CmdArgs.Explicit (flagNone)
@@ -160,14 +160,15 @@ confirmedTransactionWizard :: PrevInput -> EntryState -> [AddingStage] -> Wizard
 confirmedTransactionWizard prevInput es [] = confirmedTransactionWizard prevInput es [EnterDateAndCode]
 confirmedTransactionWizard prevInput es@EntryState{..} stack@(currentStage : _) = case currentStage of
   EnterDateAndCode -> dateAndCodeWizard prevInput es >>= \case
-    Just (date, code) -> do
-      let es' = es
-            { esArgs = drop 1 esArgs
-            , esDefDate = date
-            }
-          dateAndCodeString = formatTime defaultTimeLocale yyyymmddFormat date
+    Just (efd, code) -> do
+      let 
+        date = fromEFDay efd
+        es' = es{ esArgs = drop 1 esArgs
+                , esDefDate = date
+                }
+        dateAndCodeString = formatTime defaultTimeLocale yyyymmddFormat date
                             ++ T.unpack (if T.null code then "" else " (" <> code <> ")")
-          yyyymmddFormat = iso8601DateFormat Nothing
+        yyyymmddFormat = "%Y-%m-%d"
       confirmedTransactionWizard prevInput{prevDateAndCode=Just dateAndCodeString} es' (EnterDescAndComment (date, code) : stack)
     Nothing ->
       confirmedTransactionWizard prevInput es stack
@@ -189,7 +190,7 @@ confirmedTransactionWizard prevInput es@EntryState{..} stack@(currentStage : _)
     Nothing ->
       confirmedTransactionWizard prevInput es (drop 1 stack)
 
-  EnterNewPosting txnParams@TxnParams{..} posting -> case (esPostings, posting) of
+  EnterNewPosting txnParams@TxnParams{..} p -> case (esPostings, p) of
     ([], Nothing) ->
       confirmedTransactionWizard prevInput es (EnterAccount txnParams : stack)
     (_, Just _) ->
@@ -230,15 +231,15 @@ confirmedTransactionWizard prevInput es@EntryState{..} stack@(currentStage : _)
       confirmedTransactionWizard prevInput es{esPostings=init esPostings} (dropWhile notPrevAmountAndNotEnterDesc stack)
 
   EnterAmountAndComment txnParams account -> amountAndCommentWizard prevInput es >>= \case
-    Just (amount, comment) -> do
-      let posting = nullposting{paccount=T.pack $ stripbrackets account
-                               ,pamount=mixedAmount amount
-                               ,pcomment=comment
-                               ,ptype=accountNamePostingType $ T.pack account
-                               }
-          amountAndCommentString = showAmount amount ++ T.unpack (if T.null comment then "" else "  ;" <> comment)
+    Just (amt, comment) -> do
+      let p = nullposting{paccount=T.pack $ stripbrackets account
+                          ,pamount=mixedAmount amt
+                          ,pcomment=comment
+                          ,ptype=accountNamePostingType $ T.pack account
+                          }
+          amountAndCommentString = showAmount amt ++ T.unpack (if T.null comment then "" else "  ;" <> comment)
           prevAmountAndCmnt' = replaceNthOrAppend (length esPostings) amountAndCommentString (prevAmountAndCmnt prevInput)
-          es' = es{esPostings=esPostings++[posting], esArgs=drop 2 esArgs}
+          es' = es{esPostings=esPostings++[p], esArgs=drop 2 esArgs}
       confirmedTransactionWizard prevInput{prevAmountAndCmnt=prevAmountAndCmnt'} es' (EnterNewPosting txnParams (Just posting) : stack)
     Nothing -> confirmedTransactionWizard prevInput es (drop 1 stack)
 
@@ -258,7 +259,7 @@ confirmedTransactionWizard prevInput es@EntryState{..} stack@(currentStage : _)
 
 dateAndCodeWizard PrevInput{..} EntryState{..} = do
   let def = headDef (T.unpack $ showDate esDefDate) esArgs
-  retryMsg "A valid hledger smart date is required. Eg: 2014/2/14, 14, yesterday." $
+  retryMsg "A valid hledger smart date is required. Eg: 2022-08-30, 8/30, 30, yesterday." $
    parser (parseSmartDateAndCode esToday) $
    withCompletion (dateCompleter def) $
    defaultTo' def $ nonEmpty $
@@ -310,18 +311,18 @@ accountWizard PrevInput{..} EntryState{..} = do
     where
       canfinish = not (null esPostings) && postingsBalanced esPostings
       parseAccountOrDotOrNull :: String -> Bool -> String -> Maybe (Maybe String)
-      parseAccountOrDotOrNull _  _ "<"       = dbg1 $ Just Nothing
-      parseAccountOrDotOrNull _  _ "."       = dbg1 $ Just $ Just "." -- . always signals end of txn
-      parseAccountOrDotOrNull "" True ""     = dbg1 $ Just $ Just ""  -- when there's no default and txn is balanced, "" also signals end of txn
-      parseAccountOrDotOrNull def@(_:_) _ "" = dbg1 $ Just $ Just def -- when there's a default, "" means use that
-      parseAccountOrDotOrNull _ _ s          = dbg1 $ fmap (Just . T.unpack) $
+      parseAccountOrDotOrNull _  _ "<"       = dbg' $ Just Nothing
+      parseAccountOrDotOrNull _  _ "."       = dbg' $ Just $ Just "." -- . always signals end of txn
+      parseAccountOrDotOrNull "" True ""     = dbg' $ Just $ Just ""  -- when there's no default and txn is balanced, "" also signals end of txn
+      parseAccountOrDotOrNull def@(_:_) _ "" = dbg' $ Just $ Just def -- when there's a default, "" means use that
+      parseAccountOrDotOrNull _ _ s          = dbg' $ fmap (Just . T.unpack) $
         either (const Nothing) validateAccount $
           flip evalState esJournal $ runParserT (accountnamep <* eof) "" (T.pack s) -- otherwise, try to parse the input as an accountname
         where
           validateAccount :: Text -> Maybe Text
           validateAccount t | no_new_accounts_ esOpts && notElem t (journalAccountNamesDeclaredOrImplied esJournal) = Nothing
                             | otherwise = Just t
-      dbg1 = id -- strace
+      dbg' = id -- strace
 
 amountAndCommentWizard PrevInput{..} EntryState{..} = do
   let pnum = length esPostings + 1
@@ -390,8 +391,9 @@ maybeExit = parser (\s -> if s=="." then throw UnexpectedEOF else Just s)
 dateCompleter :: String -> CompletionFunc IO
 dateCompleter = completer ["today","tomorrow","yesterday"]
 
+-- Offer payees declared, payees used, or full descriptions used.
 descriptionCompleter :: Journal -> String -> CompletionFunc IO
-descriptionCompleter j = completer (map T.unpack $ journalDescriptions j)
+descriptionCompleter j = completer (map T.unpack $ nub $ journalPayeesDeclaredOrUsed j ++ journalDescriptions j)
 
 accountCompleter :: Journal -> String -> CompletionFunc IO
 accountCompleter j = completer (map T.unpack $ journalAccountNamesDeclaredOrImplied j)
