@@ -277,7 +277,7 @@ import qualified Text.Tabular.AsciiWide as Tab
 import Hledger
 import Hledger.Cli.CliOptions
 import Hledger.Cli.Utils
-import Hledger.Read.CsvUtils (CSV, printCSV)
+import Hledger.Read.CsvUtils (CSV, printCSV, printTSV)
 
 
 -- | Command line options for this command.
@@ -315,6 +315,7 @@ balancemode = hledgerCommandMode
     ,flagNone ["average","A"] (setboolopt "average") "show a row average column (in multicolumn reports)"
     ,flagNone ["related","r"] (setboolopt "related") "show postings' siblings instead"
     ,flagNone ["row-total","T"] (setboolopt "row-total") "show a row total column (in multicolumn reports)"
+    ,flagNone ["summary-only"] (setboolopt "summary-only") "display only row summaries (e.g. row total, average) (in multicolumn reports)"
     ,flagNone ["no-total","N"] (setboolopt "no-total") "omit the final total row"
     ,flagNone ["no-elide"] (setboolopt "no-elide") "don't squash boring parent accounts (in tree mode)"
     ,flagReq  ["format"] (\s opts -> Right $ setopt "format" s opts) "FORMATSTR" "use this custom line format (in simple reports)"
@@ -331,7 +332,7 @@ balancemode = hledgerCommandMode
         ,"'tidy'        : every attribute in its own column"
         ])
     -- output:
-    ,outputFormatFlag ["txt","html","csv","json"]
+    ,outputFormatFlag ["txt","html","csv","tsv","json"]
     ,outputFileFlag
     ]
   )
@@ -347,37 +348,42 @@ balance :: CliOpts -> Journal -> IO ()
 balance opts@CliOpts{reportspec_=rspec} j = case balancecalc_ of
     CalcBudget -> do  -- single or multi period budget report
       let rspan = fst $ reportSpan j rspec
-          budgetreport = budgetReport rspec (balancingopts_ $ inputopts_ opts) rspan j
+          budgetreport = styleAmounts styles $ budgetReport rspec (balancingopts_ $ inputopts_ opts) rspan j
           render = case fmt of
             "txt"  -> budgetReportAsText ropts
             "json" -> (<>"\n") . toJsonText
             "csv"  -> printCSV . budgetReportAsCsv ropts
+            "tsv"  -> printTSV . budgetReportAsCsv ropts
             _      -> error' $ unsupportedOutputFormatError fmt
       writeOutputLazyText opts $ render budgetreport
 
     _ | multiperiod -> do  -- multi period balance report
-        let report = multiBalanceReport rspec j
+        let report = styleAmounts styles $ multiBalanceReport rspec j
             render = case fmt of
               "txt"  -> multiBalanceReportAsText ropts
               "csv"  -> printCSV . multiBalanceReportAsCsv ropts
+              "tsv"  -> printTSV . multiBalanceReportAsCsv ropts
               "html" -> (<>"\n") . L.renderText . multiBalanceReportAsHtml ropts
               "json" -> (<>"\n") . toJsonText
               _      -> const $ error' $ unsupportedOutputFormatError fmt  -- PARTIAL:
         writeOutputLazyText opts $ render report
 
     _ -> do  -- single period simple balance report
-        let report = balanceReport rspec j -- simple Ledger-style balance report
+        let report = styleAmounts styles $ balanceReport rspec j -- simple Ledger-style balance report
             render = case fmt of
               "txt"  -> \ropts1 -> TB.toLazyText . balanceReportAsText ropts1
               "csv"  -> \ropts1 -> printCSV . balanceReportAsCsv ropts1
+              "tsv"  -> \ropts1 -> printTSV . balanceReportAsCsv ropts1
               -- "html" -> \ropts -> (<>"\n") . L.renderText . multiBalanceReportAsHtml ropts . balanceReportAsMultiBalanceReport ropts
               "json" -> const $ (<>"\n") . toJsonText
               _      -> error' $ unsupportedOutputFormatError fmt  -- PARTIAL:
         writeOutputLazyText opts $ render ropts report
   where
+    styles = journalCommodityStylesWith HardRounding j
     ropts@ReportOpts{..} = _rsReportOpts rspec
-    -- Tidy csv should be consistent between single period and multiperiod reports.
-    multiperiod = interval_ /= NoInterval || (layout_ == LayoutTidy && fmt == "csv")
+    -- Tidy csv/tsv should be consistent between single period and multiperiod reports.
+    multiperiod = interval_ /= NoInterval || (layout_ == LayoutTidy && delimited)
+    delimited   = fmt == "csv" || fmt == "tsv"
     fmt         = outputFormatFromOpts opts
 
 -- XXX this allows rough HTML rendering of a flat BalanceReport, but it can't handle tree mode etc.
@@ -428,8 +434,11 @@ balanceReportAsCsv opts (items, total) =
 
     showName = accountNameDrop (drop_ opts)
     renderAmount amt = wbToText $ showMixedAmountB bopts amt
-      where bopts = csvDisplay{displayOrder = order}
-            order = if layout_ opts == LayoutBare then Just (S.toList $ maCommodities amt) else Nothing
+      where
+        bopts = csvDisplay{displayCommodity=showcomm, displayCommodityOrder = commorder}
+        (showcomm, commorder)
+          | layout_ opts == LayoutBare = (False, Just $ S.toList $ maCommodities amt)
+          | otherwise                  = (True, Nothing)
 
 -- | Render a single-column balance report as plain text.
 balanceReportAsText :: ReportOpts -> BalanceReport -> TB.Builder
@@ -461,7 +470,7 @@ balanceReportAsText' opts ((items, total)) =
         [ Cell TopRight damts
         , Cell TopLeft (fmap wbFromText cs)
         , Cell TopLeft (replicate (length damts - 1) mempty ++ [wbFromText dispname]) ]
-      where dopts = oneLine{displayColour=color_ opts, displayOrder=Just cs}
+      where dopts = oneLine{displayCommodity=layout_ opts /= LayoutBare, displayCommodityOrder=Just cs, displayColour=color_ opts}
             cs    = if mixedAmountLooksZero amt then [""] else S.toList $ maCommodities amt
             dispname = T.replicate ((dep - 1) * 2) " " <> acctname
             damts = showMixedAmountLinesB dopts amt
@@ -518,7 +527,12 @@ renderComponent topaligned oneline opts (acctname, dep, total) (FormatField ljus
           | topaligned          = TopRight
           | ljust               = BottomLeft
           | otherwise           = BottomRight
-    dopts = noPrice{displayColour=color_ opts, displayOneLine=oneline, displayMinWidth=mmin, displayMaxWidth=mmax}
+    dopts = noCost{displayCommodity = layout_ opts /= LayoutBare
+                  ,displayOneLine   = oneline
+                  ,displayMinWidth  = mmin
+                  ,displayMaxWidth  = mmax
+                  ,displayColour    = color_ opts
+                  }
 
 -- rendering multi-column balance reports
 
@@ -692,7 +706,7 @@ multiBalanceReportAsText ropts@ReportOpts{..} r = TB.toLazyText $
 
 -- | Build a 'Table' from a multi-column balance report.
 balanceReportAsTable :: ReportOpts -> MultiBalanceReport -> Table T.Text T.Text WideBuilder
-balanceReportAsTable opts@ReportOpts{average_, row_total_, balanceaccum_}
+balanceReportAsTable opts@ReportOpts{summary_only_, average_, row_total_, balanceaccum_}
     (PeriodicReport spans items tr) =
    maybetranspose $
    addtotalrow $
@@ -703,7 +717,7 @@ balanceReportAsTable opts@ReportOpts{average_, row_total_, balanceaccum_}
   where
     totalscolumn = row_total_ && balanceaccum_ `notElem` [Cumulative, Historical]
     colheadings = ["Commodity" | layout_ opts == LayoutBare]
-                  ++ map (reportPeriodName balanceaccum_ spans) spans
+                  ++ (if not summary_only_ then map (reportPeriodName balanceaccum_ spans) spans else [])
                   ++ ["  Total" | totalscolumn]
                   ++ ["Average" | average_]
     fullRowAsTexts row =
@@ -731,18 +745,20 @@ multiBalanceRowAsWbs bopts ReportOpts{..} colspans (PeriodicReportRow _ as rowto
                            $ allamts
       LayoutBare       -> zipWith (:) (fmap wbFromText cs)  -- add symbols
                            . transpose                         -- each row becomes a list of Text quantities
-                           . fmap (showMixedAmountLinesB bopts{displayOrder=Just cs, displayMinWidth=Nothing})
+                           . fmap (showMixedAmountLinesB bopts{displayCommodity=False, displayCommodityOrder=Just cs, displayMinWidth=Nothing})
                            $ allamts
       LayoutTidy       -> concat
                            . zipWith (map . addDateColumns) colspans
                            . fmap ( zipWith (\c a -> [wbFromText c, a]) cs
-                                  . showMixedAmountLinesB bopts{displayOrder=Just cs, displayMinWidth=Nothing})
+                                  . showMixedAmountLinesB bopts{displayCommodity=False, displayCommodityOrder=Just cs, displayMinWidth=Nothing})
                            $ as  -- Do not include totals column or average for tidy output, as this
                                  -- complicates the data representation and can be easily calculated
   where
     totalscolumn = row_total_ && balanceaccum_ `notElem` [Cumulative, Historical]
     cs = if all mixedAmountLooksZero allamts then [""] else S.toList $ foldMap maCommodities allamts
-    allamts = as ++ [rowtot | totalscolumn && not (null as)] ++ [rowavg | average_ && not (null as)]
+    allamts = (if not summary_only_ then as else []) ++
+                [rowtot | totalscolumn && not (null as)] ++
+                [rowavg | average_ && not (null as)]
     addDateColumns spn@(DateSpan s e) = (wbFromText (showDateSpan spn) :)
                                        . (wbFromText (maybe "" showEFDate s) :)
                                        . (wbFromText (maybe "" (showEFDate . modifyEFDay (addDays (-1))) e) :)
