@@ -62,11 +62,18 @@ roi ::  CliOpts -> Journal -> IO ()
 roi CliOpts{rawopts_=rawopts, reportspec_=rspec@ReportSpec{_rsReportOpts=ReportOpts{..}}} j = do
   -- We may be converting posting amounts to value, per hledger_options.m4.md "Effect of --value on reports".
   let
+    -- lbl = lbl_ "roi"
     today = _rsDay rspec
     priceOracle = journalPriceOracle infer_prices_ j
-    styles = journalCommodityStyles j
+    styles = journalCommodityStylesWith HardRounding j
     mixedAmountValue periodlast date =
-        maybe id (mixedAmountApplyValuation priceOracle styles periodlast today date) value_
+        -- These calculations can generate very precise decimals. To avoid showing too many digits:
+        -- If we have no style for the valuation commodity, generate one that will limit the precision ?
+        -- But it's not easy to find out the valuation commodity (or commodities) here if it's implicit,
+        -- as that information is buried in the price graph.
+        -- Instead, do what we don't like to do: hard code a max precision, overriding commodity styles.
+        mixedAmountSetPrecisionMax defaultMaxPrecision
+      . maybe id (mixedAmountApplyValuation priceOracle styles periodlast today date) value_
       . maybe id (mixedAmountToCost styles) conversionop_
 
   let
@@ -89,69 +96,89 @@ roi CliOpts{rawopts_=rawopts, reportspec_=rspec@ReportSpec{_rsReportOpts=ReportO
     putStrLn "No relevant transactions found. Check your investments query"
     exitFailure
 
-  let spans = snd $ reportSpan filteredj rspec
+  let (fullPeriod, spans) = reportSpan filteredj rspec
 
   let priceDirectiveDates = dbg3 "priceDirectiveDates" $ map pddate $ jpricedirectives j
 
-  tableBody <- forM spans $ \spn@(DateSpan (Just begin) (Just end)) -> do
-    -- Spans are [begin,end), and end is 1 day after the actual end date we are interested in
-    let
-      b = fromEFDay begin
-      e = fromEFDay end
-      cashFlowApplyCostValue = map (\(d,amt) -> (d,mixedAmountValue e d amt))
+  let processSpan (DateSpan Nothing _) = error "Undefined start of the period - will be unable to compute the rates of return"
+      processSpan (DateSpan _ Nothing) = error "Undefined end of the period - will be unable to compute the rates of return"
+      processSpan spn@(DateSpan (Just begin) (Just end)) = do
+        -- Spans are [begin,end), and end is 1 day after the actual end date we are interested in
+        let
+          b = fromEFDay begin
+          e = fromEFDay end
+          cashFlowApplyCostValue = map (\(d,amt) -> (d,mixedAmountValue e d amt))
 
-      valueBefore =
-        mixedAmountValue e b $ 
-        total trans (And [ investmentsQuery
-                         , Date (DateSpan Nothing (Just begin))])
+          valueBefore =
+            mixedAmountValue e b $
+            total trans (And [ investmentsQuery
+                             , Date (DateSpan Nothing (Just begin))])
 
-      valueAfter  =
-        mixedAmountValue e e $ 
-        total trans (And [investmentsQuery
-                         , Date (DateSpan Nothing (Just end))])
+          valueAfter  =
+            mixedAmountValue e e $
+            total trans (And [investmentsQuery
+                             , Date (DateSpan Nothing (Just end))])
 
-      priceDates = dbg3 "priceDates" $ nub $ filter (spanContainsDate spn) priceDirectiveDates
-      cashFlow =
-        ((map (,nullmixedamt) priceDates)++) $
-        cashFlowApplyCostValue $
-        calculateCashFlow wd trans (And [ Not investmentsQuery
-                                        , Not pnlQuery
-                                        , Date spn ] )
+          priceDates = dbg3 "priceDates" $ nub $ filter (spanContainsDate spn) priceDirectiveDates
+          cashFlow =
+            ((map (,nullmixedamt) priceDates)++) $
+            cashFlowApplyCostValue $
+            calculateCashFlow wd trans (And [ Not investmentsQuery
+                                            , Not pnlQuery
+                                            , Date spn ] )
 
+          pnl =
+            cashFlowApplyCostValue $
+            calculateCashFlow wd trans (And [ Not investmentsQuery
+                                            , pnlQuery
+                                            , Date spn ] )
 
-      pnl =
-        cashFlowApplyCostValue $
-        calculateCashFlow wd trans (And [ Not investmentsQuery
-                                        , pnlQuery
-                                        , Date spn ] )
+          thisSpan = dbg3 "processing span" $
+                     OneSpan b e valueBefore valueAfter cashFlow pnl
 
-      thisSpan = dbg3 "processing span" $
-                 OneSpan b e valueBefore valueAfter cashFlow pnl
+        irr <- internalRateOfReturn styles showCashFlow prettyTables thisSpan
+        (periodTwr, annualizedTwr) <- timeWeightedReturn styles showCashFlow prettyTables investmentsQuery trans mixedAmountValue thisSpan
+        let cashFlowAmt = maNegate . maSum $ map snd cashFlow
+        let smallIsZero x = if abs x < 0.01 then 0.0 else x
+        return [ showDate b
+               , showDate (addDays (-1) e)
+               , T.pack $ showMixedAmount $ styleAmounts styles $ valueBefore
+               , T.pack $ showMixedAmount $ styleAmounts styles $ cashFlowAmt
+               -- , T.pack $ showMixedAmount $
+               --   -- dbg0With (lbl "cashflow after styling".showMixedAmountOneLine) $
+               --   mapMixedAmount (amountSetFullPrecisionOr (Just defaultMaxPrecision)) $
+               --   styleAmounts (styles
+               --                 -- & dbg0With (lbl "styles".show))
+               --   cashFlowAmt
+               --   -- & dbg0With (lbl "cashflow before styling".showMixedAmountOneLine)
+               , T.pack $ showMixedAmount $ styleAmounts styles $ valueAfter
+               , T.pack $ showMixedAmount $ styleAmounts styles $ (valueAfter `maMinus` (valueBefore `maPlus` cashFlowAmt))
+               , T.pack $ printf "%0.2f%%" $ smallIsZero irr
+               , T.pack $ printf "%0.2f%%" $ smallIsZero periodTwr
+               , T.pack $ printf "%0.2f%%" $ smallIsZero annualizedTwr ]
 
-    irr <- internalRateOfReturn showCashFlow prettyTables thisSpan
-    twr <- timeWeightedReturn showCashFlow prettyTables investmentsQuery trans mixedAmountValue thisSpan
-    let cashFlowAmt = maNegate . maSum $ map snd cashFlow
-    let smallIsZero x = if abs x < 0.01 then 0.0 else x
-    return [ showDate b
-           , showDate (addDays (-1) e)
-           , T.pack $ showMixedAmount valueBefore
-           , T.pack $ showMixedAmount cashFlowAmt
-           , T.pack $ showMixedAmount valueAfter
-           , T.pack $ showMixedAmount (valueAfter `maMinus` (valueBefore `maPlus` cashFlowAmt))
-           , T.pack $ printf "%0.2f%%" $ smallIsZero irr
-           , T.pack $ printf "%0.2f%%" $ smallIsZero twr ]
+  periodRows <- forM spans processSpan
+  totalRow <- processSpan fullPeriod
+
+  let rowTitles = Tab.Group Tab.NoLine (map (Header . T.pack . show) (take (length periodRows) [1..]))
+
+  let isSingleSpan = length spans == 1
 
   let table = Table
-              (Tab.Group Tab.NoLine (map (Header . T.pack . show) (take (length tableBody) [1..])))
+              (if isSingleSpan
+                then rowTitles
+                else Tab.Group Tab.SingleLine  [ rowTitles, Tab.Group Tab.NoLine [ Header "Total" ]]
+              )
               (Tab.Group Tab.DoubleLine
                [ Tab.Group Tab.SingleLine [Header "Begin", Header "End"]
                , Tab.Group Tab.SingleLine [Header "Value (begin)", Header "Cashflow", Header "Value (end)", Header "PnL"]
-               , Tab.Group Tab.SingleLine [Header "IRR", Header "TWR"]])
-              tableBody
+               , Tab.Group Tab.SingleLine [Header "IRR"]
+               , Tab.Group Tab.SingleLine [Header "TWR/period", Header "TWR/year"]])
+              (if isSingleSpan then periodRows else periodRows ++ [totalRow])
 
   TL.putStrLn $ Tab.render prettyTables id id id table
 
-timeWeightedReturn showCashFlow prettyTables investmentsQuery trans mixedAmountValue (OneSpan begin end valueBeforeAmt valueAfter cashFlow pnl) = do
+timeWeightedReturn styles showCashFlow prettyTables investmentsQuery trans mixedAmountValue (OneSpan begin end valueBeforeAmt valueAfter cashFlow pnl) = do
   let valueBefore = unMix valueBeforeAmt
   let initialUnitPrice = 100 :: Decimal
   let initialUnits = valueBefore / initialUnitPrice
@@ -174,7 +201,7 @@ timeWeightedReturn showCashFlow prettyTables investmentsQuery trans mixedAmountV
         where
           zeroUnitsNeedsCashflowAtTheFront changes1 =
             if initialUnits > 0 then changes1
-            else 
+            else
               let (leadingEmptyCashFlows, rest) = span isEmptyCashflow changes1
                   (leadingPnls, rest') = span (isLeft . snd) rest
                   (firstCashflow, rest'') = splitAt 1 rest'
@@ -185,10 +212,10 @@ timeWeightedReturn showCashFlow prettyTables investmentsQuery trans mixedAmountV
             Left _     -> False
 
           datedPnls = map (second Left) $ aggregateByDate pnl
- 
+
           datedCashflows = map (second Right) $ aggregateByDate cashFlow
 
-          aggregateByDate datedAmounts = 
+          aggregateByDate datedAmounts =
             -- Aggregate all entries for a single day, assuming that intraday interest is negligible
             sort
             $ map (\date_cash -> let (dates, cash) = unzip date_cash in (head dates, maSum cash))
@@ -223,7 +250,8 @@ timeWeightedReturn showCashFlow prettyTables investmentsQuery trans mixedAmountV
                        else (unMix valueAfter) / finalUnitBalance
       -- Technically, totalTWR should be (100*(finalUnitPrice - initialUnitPrice) / initialUnitPrice), but initalUnitPrice is 100, so 100/100 == 1
       totalTWR = roundTo 2 $ (finalUnitPrice - initialUnitPrice)
-      years = fromIntegral (diffDays end begin) / 365 :: Double
+      (startYear, _, _) = toGregorian begin
+      years = fromIntegral (diffDays end begin) / (if isLeapYear startYear then 366 else 365) :: Double
       annualizedTWR = 100*((1+(realToFrac totalTWR/100))**(1/years)-1) :: Double
 
   when showCashFlow $ do
@@ -249,17 +277,17 @@ timeWeightedReturn showCashFlow prettyTables investmentsQuery trans mixedAmountV
        | val <- map showDecimal valuesOnDate
        | oldBalance <- map showDecimal (0:unitBalances)
        | balance <- map showDecimal unitBalances
-       | pnl' <- map showMixedAmount pnls
-       | cashflow <- map showMixedAmount cashflows
+       | pnl' <- map (showMixedAmount . styleAmounts styles) pnls
+       | cashflow <- map (showMixedAmount . styleAmounts styles) cashflows
        | prc <- map showDecimal unitPrices
        | udelta <- map showDecimal unitsBoughtOrSold ])
 
     printf "Final unit price: %s/%s units = %s\nTotal TWR: %s%%.\nPeriod: %.2f years.\nAnnualized TWR: %.2f%%\n\n"
-      (showMixedAmount valueAfter) (showDecimal finalUnitBalance) (showDecimal finalUnitPrice) (showDecimal totalTWR) years annualizedTWR
+      (showMixedAmount $ styleAmounts styles valueAfter) (showDecimal finalUnitBalance) (showDecimal finalUnitPrice) (showDecimal totalTWR) years annualizedTWR
 
-  return annualizedTWR
+  return ((realToFrac totalTWR) :: Double, annualizedTWR)
 
-internalRateOfReturn showCashFlow prettyTables (OneSpan begin end valueBefore valueAfter cashFlow _pnl) = do
+internalRateOfReturn styles showCashFlow prettyTables (OneSpan begin end valueBefore valueAfter cashFlow _pnl) = do
   let prefix = (begin, maNegate valueBefore)
 
       postfix = (end, valueAfter)
@@ -273,7 +301,7 @@ internalRateOfReturn showCashFlow prettyTables (OneSpan begin end valueBefore va
       (Table
        (Tab.Group Tab.NoLine (map (Header . showDate) dates))
        (Tab.Group Tab.SingleLine [Header "Amount"])
-       (map ((:[]) . T.pack . showMixedAmount) amts))
+       (map ((:[]) . T.pack . showMixedAmount . styleAmounts styles) amts))
 
   -- 0% is always a solution, so require at least something here
   case totalCF of
@@ -314,5 +342,3 @@ showDecimal :: Decimal -> String
 showDecimal d = if d == rounded then show d else show rounded
   where
     rounded = roundTo 2 d
-
-
