@@ -20,7 +20,6 @@ module Hledger.Cli.Utils
      openBrowserOn,
      writeFileWithBackup,
      writeFileWithBackupIfChanged,
-     readFileStrictly,
      pivotByOpts,
      anonymiseByOpts,
      journalSimilarTransaction,
@@ -29,7 +28,6 @@ module Hledger.Cli.Utils
     )
 where
 
-import Control.Exception as C
 import Control.Monad.Except (ExceptT)
 import Control.Monad.IO.Class (liftIO)
 import Data.List
@@ -59,6 +57,7 @@ import Hledger.Read
 import Hledger.Reports
 import Hledger.Utils
 import Control.Monad (when)
+import Data.Functor ((<&>))
 
 -- | Standard error message for a bad output format specified with -O/-o.
 unsupportedOutputFormatError :: String -> String
@@ -76,33 +75,42 @@ withJournalDo opts cmd = do
   j <- runExceptT $ journalTransform opts <$> readJournalFiles (inputopts_ opts) journalpaths
   either error' cmd j  -- PARTIAL:
 
--- | Apply some extra post-parse transformations to the journal, if
--- specified by options. These happen after journal validation, but
--- before report calculation. They include:
+-- | Apply some extra post-parse transformations to the journal, if enabled by options.
+-- These happen after parsing and finalising the journal, but before report calculation.
+-- They are, in processing order:
 --
--- - adding forecast transactions (--forecast)
 -- - pivoting account names (--pivot)
+--
 -- - anonymising (--anonymise).
 --
--- This will return an error message if the query in any auto posting rule fails
--- to parse, or the generated transactions are not balanced.
 journalTransform :: CliOpts -> Journal -> Journal
 journalTransform opts =
-    anonymiseByOpts opts
-  -- - converting amounts to market value (--value)
-  -- . journalApplyValue ropts
-  . pivotByOpts opts
+      pivotByOpts opts
+  <&> anonymiseByOpts opts
+  <&> maybeObfuscate opts
 
--- | Apply the pivot transformation on a journal, if option is present.
+-- | Apply the pivot transformation on a journal (replacing account names by a different field's value), if option is present.
 pivotByOpts :: CliOpts -> Journal -> Journal
 pivotByOpts opts =
   case maybestringopt "pivot" . rawopts_ $ opts of
     Just tag -> journalPivot $ T.pack tag
     Nothing  -> id
 
--- | Apply the anonymisation transformation on a journal, if option is present
+-- #2133
+-- | Raise an error, announcing the rename to --obfuscate and its limitations.
 anonymiseByOpts :: CliOpts -> Journal -> Journal
 anonymiseByOpts opts =
+  if boolopt "anon" $ rawopts_ opts
+    then error' $ unlines [
+       "--anon does not give privacy, and perhaps should be avoided;"
+      ,"please see https://github.com/simonmichael/hledger/issues/2133 ."
+      ,"For now it has been renamed to --obfuscate (a hidden flag)."
+      ]
+    else id
+
+-- | Apply light obfuscation to a journal, if --obfuscate is present (formerly --anon).
+maybeObfuscate :: CliOpts -> Journal -> Journal
+maybeObfuscate opts =
   if anon_ . inputopts_ $ opts
       then anon
       else id
@@ -223,9 +231,6 @@ writeFileWithBackupIfChanged f t = do
 writeFileWithBackup :: FilePath -> String -> IO ()
 writeFileWithBackup f t = backUpFile f >> writeFile f t
 
-readFileStrictly :: FilePath -> IO T.Text
-readFileStrictly f = readFilePortably f >>= \s -> C.evaluate (T.length s) >> return s
-
 -- | Back up this file with a (incrementing) numbered suffix, or give an error.
 backUpFile :: FilePath -> IO ()
 backUpFile fp = do
